@@ -15,8 +15,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.apache.druid.hooks.druid import DruidHook
@@ -30,15 +31,11 @@ class DruidOperator(BaseOperator):
     Allows to submit a task directly to druid
 
     :param json_index_file: The filepath to the druid index specification
-    :type json_index_file: str
     :param druid_ingest_conn_id: The connection id of the Druid overlord which
         accepts index jobs
-    :type druid_ingest_conn_id: str
     :param timeout: The interval (in seconds) between polling the Druid job for the status
         of the ingestion job. Must be greater than or equal to 1
-    :type timeout: int
     :param max_ingestion_time: The maximum ingestion time before assuming the job failed
-    :type max_ingestion_time: int
     """
 
     template_fields: Sequence[str] = ('json_index_file',)
@@ -51,7 +48,7 @@ class DruidOperator(BaseOperator):
         json_index_file: str,
         druid_ingest_conn_id: str = 'druid_ingest_default',
         timeout: int = 1,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
@@ -60,7 +57,7 @@ class DruidOperator(BaseOperator):
         self.timeout = timeout
         self.max_ingestion_time = max_ingestion_time
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hook = DruidHook(
             druid_ingest_conn_id=self.conn_id,
             timeout=self.timeout,
